@@ -1,6 +1,8 @@
 
 import unittest
 
+from assertions import *
+
 from testfixtures import log_capture
 
 from slimta.logging import logline, parseline, log_exception
@@ -10,7 +12,7 @@ class TestLogging(unittest.TestCase):
 
     def _check_logline(self, expected):
         def check(data):
-            self.assertEqual(expected, data)
+            assert_equal(expected, data)
         return check
 
     def test_logline_nodata(self):
@@ -24,36 +26,36 @@ class TestLogging(unittest.TestCase):
     def test_parseline_nodata(self):
         line = 'test:jkl:nodata'
         type, id, op, data = parseline(line)
-        self.assertEqual('test', type)
-        self.assertEqual('jkl', id)
-        self.assertEqual('nodata', op)
-        self.assertEqual({}, data)
+        assert_equal('test', type)
+        assert_equal('jkl', id)
+        assert_equal('nodata', op)
+        assert_equal({}, data)
 
     def test_parseline_withdata(self):
         line = 'test:jkl:withdata one=1 two=\'two\''
         type, id, op, data = parseline(line)
-        self.assertEqual('test', type)
-        self.assertEqual('jkl', id)
-        self.assertEqual('withdata', op)
-        self.assertEqual({'one': 1, 'two': 'two'}, data)
+        assert_equal('test', type)
+        assert_equal('jkl', id)
+        assert_equal('withdata', op)
+        assert_equal({'one': 1, 'two': 'two'}, data)
 
     def test_parseline_badbeginning(self):
-        with self.assertRaises(ValueError):
+        with assert_raises(ValueError):
             parseline('bad!')
 
     def test_parseline_baddata(self):
         line = 'test:jkl:baddata one=1 two=two'
         type, id, op, data = parseline(line)
-        self.assertEqual('test', type)
-        self.assertEqual('jkl', id)
-        self.assertEqual('baddata', op)
-        self.assertEqual({'one': 1}, data)
+        assert_equal('test', type)
+        assert_equal('jkl', id)
+        assert_equal('baddata', op)
+        assert_equal({'one': 1}, data)
         line = 'test:jkl:baddata one=one two=\'two\''
         type, id, op, data = parseline(line)
-        self.assertEqual('test', type)
-        self.assertEqual('jkl', id)
-        self.assertEqual('baddata', op)
-        self.assertEqual({}, data)
+        assert_equal('test', type)
+        assert_equal('jkl', id)
+        assert_equal('baddata', op)
+        assert_equal({}, data)
 
     @log_capture()
     def test_log_exception(self, l):
@@ -62,18 +64,18 @@ class TestLogging(unittest.TestCase):
             raise ValueError('testing stuff')
         except Exception:
             log_exception('test', extra='more stuff')
-        self.assertEqual(1, len(l.records))
+        assert_equal(1, len(l.records))
         rec = l.records[0]
-        self.assertEqual('test', rec.name)
-        self.assertEqual('ERROR', rec.levelname)
+        assert_equal('test', rec.name)
+        assert_equal('ERROR', rec.levelname)
         type, id, op, data = parseline(rec.msg)
-        self.assertEqual('exception', type)
-        self.assertEqual('ValueError', id)
-        self.assertEqual('unhandled', op)
-        self.assertEqual('more stuff', data['extra'])
-        self.assertEqual(('testing stuff', ), data['args'])
-        self.assertEqual('testing stuff', data['message'])
-        self.assertTrue(data['traceback'])
+        assert_equal('exception', type)
+        assert_equal('ValueError', id)
+        assert_equal('unhandled', op)
+        assert_equal('more stuff', data['extra'])
+        assert_equal(('testing stuff', ), data['args'])
+        assert_equal('testing stuff', data['message'])
+        assert_true(data['traceback'])
 
 
 # vim:et:fdm=marker:sts=4:sw=4:ts=4
